@@ -9,7 +9,9 @@ use URI::file;
 use Config;
 
 # Make sure the svn messages come in English.
-$ENV{LC_MESSAGES} = 'C';
+# https://www.gnu.org/software/gettext/manual/html_node/Locale-Environment-Variables.html
+$ENV{LC_ALL} = 'C';
+delete $ENV{LANGUAGE};
 
 sub can_svn {
   CMD:
@@ -25,6 +27,19 @@ sub can_svn {
     return 1;
 }
 
+sub svn_version {
+    open my $pipe, '-|', "svn --version" or die;
+    my $version = <$pipe>;
+    local $/ = undef;           # slurp mode to read everything else up
+    <$pipe>;
+    close $pipe or die;
+    if ($version =~ /version ([\d\.]+)/) {
+        return $1;
+    } else {
+        die "Couldn't grok version from 'svn --version' command output: '$version'";
+    }
+}
+
 our $T;
 
 sub newdir {
@@ -113,7 +128,9 @@ EOS
     # ":/bin:/usr/bin". During the tests we try to set up the hooks so
     # that they will use the PATH as it is in the test environment.
     if (defined $ENV{PATH} and length $ENV{PATH}) {
-	print $fd "BEGIN { \$ENV{PATH} = '$ENV{PATH}' }\n";
+	my $path = $ENV{PATH};
+	$path =~ s/\\$//;
+	print $fd "BEGIN { \$ENV{PATH} = '$path' }\n";
     }
 
     if (defined $ENV{PERL5LIB} and length $ENV{PERL5LIB}) {
